==> Conjur-0.3.1.tar.gz: Conjur-0.3.1/tests/conjur_test.py <==
#
# Copyright (C) 2014 Conjur Inc
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import conjur
from conjur.config import Config, config

def test_new_from_key():
    api = conjur.new_from_key("login", "secret")
    assert api.token is None
    assert api.api_key == "secret"
    assert api.login == "login"
    assert api.config == config

def test_new_from_token():
    api = conjur.new_from_token("a token")
    assert api.token == "a token"
    assert api.api_key == None
    assert api.login == None
    assert api.config == config

def test_new_with_config():
    cfg = Config()
    api = conjur.new_from_key("login", "secret",cfg)
    assert cfg is api.config

==> Conjur-0.4.4.tar.gz: Conjur-0.4.4/tests/conjur_test.py <==
#
# Copyright (C) 2014 Conjur Inc
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import conjur
from conjur.config import Config, config


def test_new_from_key():
    api = conjur.new_from_key("login", "secret")
    assert api.token is None
    assert api.api_key == "secret"
    assert api.login == "login"
    assert api.config == config


def test_new_from_token():
    api = conjur.new_from_token("a token")
    assert api.token == "a token"
    assert api.api_key is None
    assert api.login is None
    assert api.config == config


def test_new_with_config():
    cfg = Config()
    api = conjur.new_from_key("login", "secret", cfg)
    assert cfg is api.config
